@@ -43,7 +43,6 @@
 #include "infoview.h"
 #include "snprintf.h"
 #include "stream.h"
-#include "terminal.h"
 #include "textedit.h"
 #include "textfile.h"
 #include "tools.h"
@@ -276,10 +275,11 @@ bool FileBrowser::extract_url(char *buf)
 	vfs_extra *x = (vfs_extra*)t->extra_data;*/
 	Vfs *vfs = listbox->getCurVfs();
 	if (vfs) {
-		int buflen = ht_snprintf(buf, VFS_URL_MAX, "%s:", listbox->getCurProto());
 		char fname[VFS_URL_MAX];
+		String res;
 		bin2str(fname, i.text, i.textlen);
-		vfs->canonicalize(buf+buflen, fname, listbox->getCurDir());
+		vfs->canonicalize(res, fname, listbox->getCurDir());
+		int buflen = ht_snprintf(buf, VFS_URL_MAX, "%s:%y", listbox->getCurProto(), &res);
 		return true;
 	}
 	return false;
@@ -356,7 +356,7 @@ bool file_chooser(const char *title, char *buf, int bufsize)
 		// FIXME: urls not fully supported...
 		if (ht_strncmp(b, "local:", 6) == 0) {
 			ht_strlcpy(buf, b+6, bufsize);
-			if (hist) insert_history_entry(hist, buf, 0);
+			if (hist) insert_history_entry(hist, buf, NULL);
 
 			d->done();
 			delete d;
@@ -558,14 +558,12 @@ void file_window_store_fcfg_func(ObjectStream &f, void *context)
 
 void file_project_store_fcfg_func(ObjectStream &f, void *context)
 {
-	PUT_OBJECT(f, (Object*)project);
+	PUT_OBJECT(f, project);
 }
 
 void file_project_load_fcfg_func(ObjectStream &f, void *context)
 {
-	Object *p;
-	GET_OBJECT(f, p);
-	project = p;
+	GET_OBJECT(f, project);
 }
 
 /*
@@ -822,7 +820,7 @@ void ht_project_listbox::handlemsg(htmsg *msg)
 				if (file_chooser("Add project item", fn, sizeof fn)) {
 					char ffn[HT_NAME_MAX];
 					char *dir;
-					if (sys_common_canonicalize(ffn, fn, NULL, sys_is_path_delim) == 0
+					if (sys_common_canonicalize(ffn, sizeof ffn, fn, NULL, sys_is_path_delim) == 0
 					 && sys_basename(fn, ffn) == 0
 					 && (dir = sys_dirname(ffn)) ) {
 						ht_project_item *p = new ht_project_item(fn, dir);
@@ -903,7 +901,7 @@ bool ht_project_listbox::selectEntry(void *entry)
 	int p = pos;
 	ht_project_item *i = (ht_project_item *)(*project)[p];
 	char fn[HT_NAME_MAX];
-	if (sys_common_canonicalize(fn, i->get_filename(), i->get_path(), sys_is_path_delim)==0) {
+	if (sys_common_canonicalize(fn, sizeof fn, i->get_filename(), i->get_path(), sys_is_path_delim)==0) {
 		((ht_app*)app)->create_window_file(fn, FOM_AUTO, false);
 	}
 	return true;
@@ -2013,9 +2011,8 @@ ht_window *ht_app::create_window_help(const char *file, const char *node)
 		char ff[HT_NAME_MAX], cwd[HT_NAME_MAX];
 
 		cwd[0] = 0;
-		getcwd(cwd, sizeof cwd);
-		if (strcmp(file, "hthelp.info")) {
-			sys_common_canonicalize(ff, file, cwd, sys_is_path_delim);
+		if (strcmp(file, "hthelp.info") != 0 && getcwd(cwd, sizeof cwd)) {
+			sys_common_canonicalize(ff, sizeof ff, file, cwd, sys_is_path_delim);
 		} else {
 			strcpy(ff, file);
 		}
@@ -2043,9 +2040,7 @@ ht_window *ht_app::create_window_project()
 		get_stdbounds_tool(&b);
 
 		ht_project_window *project_window=new ht_project_window();
-		ht_project *p = (ht_project *)project;
-		project_window->init(&b, "project window", FS_KILLER | FS_TITLE | FS_NUMBER | FS_MOVE | FS_RESIZE, 0, &p);
-		project = p;
+		project_window->init(&b, "project window", FS_KILLER | FS_TITLE | FS_NUMBER | FS_MOVE | FS_RESIZE, 0, (ht_project**)&project);
 
 		Bounds k = b;
 		k.x = b.w-2;
@@ -2958,18 +2953,21 @@ void ht_app::project_opencreate(const char *filename)
 {
 	char fn[HT_NAME_MAX];
 	char cwd[HT_NAME_MAX];
-	getcwd(cwd, sizeof cwd);
-	if (sys_common_canonicalize(fn, filename, cwd, sys_is_path_delim) != 0) {
+	if (getcwd(cwd, sizeof cwd) == NULL) {
+		LOG("getcwd(): %s", strerror(errno));
+		return;
+	}
+	if (sys_common_canonicalize(fn, sizeof fn, filename, cwd, sys_is_path_delim) != 0) {
 		LOG("%s: invalid filename", filename);
 		return;
 	}
-	char *suf = sys_filename_suffix(fn);
+	const char *suf = sys_filename_suffix(fn);
 	/* append HT project file suffix if not already there */
 	if (!(suf && (strcmp(suf, HT_PROJECT_CONFIG_SUFFIX+1)==0))) {
 		strcat(fn, HT_PROJECT_CONFIG_SUFFIX);
 	}
 
-	void *old_project = project;
+	Object *old_project = project;
 	project = NULL;
 
 	String einfo;
